@@ -25,7 +25,7 @@ def strict_equality_checker(val, ref):
     output or value. If there is a difference, some kind of diff is
     printed, depending on the types of the values.
     """
-    if val == ref:
+    if type(val) == type(ref) and val == ref:
         val_repr = repr(val)
         if isinstance(val, str) and '\n' in val:
             val_repr = val
@@ -188,6 +188,45 @@ def numbers_are_equalish(val, ref):
 # String comparison #
 #-------------------#
 
+def multiline_strings_are_exactly_equal(val, ref):
+    """
+    A checker to be used with harnesses which generate multi-line strings
+    where the outputs can reasonable be expected to be exactly equal.
+    Displays results more nicely than omni_compare because it knows
+    they'll be strings.
+    """
+    if not isinstance(val, str) or not isinstance(ref, str):
+        raise TypeError(
+            (
+                "Can't check string equality for non-string value(s):\n"
+              + "{}\nand\n{}"
+            ).format(repr(val), repr(ref))
+        )
+
+    if val == ref:
+        return {
+            "status": "accomplished",
+            "explanation": "Values are the same.<br>\n{}".format(
+                html_tools.html_output_details(val, "Value tested")
+            )
+        }
+    else:
+        val_lines = val.splitlines(keepends=True)
+        ref_lines = ref.splitlines(keepends=True)
+        diffTable = html_tools.html_diff_table(
+            val_lines,
+            ref_lines,
+            "Actual result",
+            "Corresponding lines (if any) in expected result"
+        )
+        return {
+            "status": "failed",
+            "explanation": "Values are different.<br>\n{}".format(
+                diffTable
+            )
+        }
+
+
 def strings_are_equal_modulo_whitespace(val, ref, ignore_case=True):
     """
     A checker to be used with OutputTest or ValueTest goals that checks
@@ -1752,7 +1791,7 @@ def omni_compare(val, ref):
         return {
             "status": "accomplished",
             "explanation": (
-                f"Actual value is the same as the reference"
+                f"Actuall value is the same as the reference"
                 f" value.<br>\n{html_tools.dynamic_html_repr(val)}"
             )
         }
@@ -1777,9 +1816,9 @@ def omni_compare(val, ref):
             return {
                 "status": "failed",
                 "explanation": (
-                    f"Your result was {phrasing.a_an(type(val))},"
+                    f"Your result was {phrasing.a_an(str(type(val)))},"
                     f" but the correct result was"
-                    f" {phrasing.a_an(type(ref))}."
+                    f" {phrasing.a_an(str(type(ref)))}."
                 )
             }
         elif isinstance(val, str): # both strings
