@@ -30,6 +30,7 @@ import shutil
 from ._version import __version__
 from . import logging
 from . import file_utils
+from . import time_utils
 from . import load
 from . import rubrics
 from . import render
@@ -584,12 +585,12 @@ def launch_job(
                     # Pull basic info from whole-pset entry
                     record = {
                         "id": pset["id"],
-                        "release": file_utils.task_time__time(
+                        "release": time_utils.task_time__time(
                             tasks_data,
                             pset["release"],
                             tasks_data.get("default_release_time_of_day")
                         ),
-                        "due": file_utils.task_time__time(
+                        "due": time_utils.task_time__time(
                             tasks_data,
                             pset["due"],
                             tasks_data.get("default_due_time_of_day")
@@ -876,7 +877,7 @@ def launch_evaluation(
     os.makedirs(report_dir, exist_ok=True)
 
     if report_filename is None:
-        timestamp = file_utils.timestamp()
+        timestamp = time_utils.timestring()
         report_filename = os.path.join(
             report_dir,
             f"{taskid}_{timestamp}.json"
