@@ -391,13 +391,13 @@ def payload_description(
             mod = ""
 
         if obfuscated:
-            topic = "The {what} of your program"
+            topic = f"The {what} of your program"
             details = (
                 f"We will run your submitted code{mod} and record"
                 f" the {what}."
             )
         else:
-            topic = "The {what} of your program"
+            topic = f"The {what} of your program"
             details = (
                 f"We ran your submitted code{mod} and recorded"
                 f" the {what}."
