@@ -28,7 +28,6 @@ import re
 import traceback
 import shelve
 import os
-import datetime
 import ast
 
 import turtle
@@ -39,7 +38,7 @@ from . import context_utils
 from . import html_tools
 from . import timeout
 from . import logging
-from . import file_utils
+from . import time_utils
 
 
 #---------#
@@ -584,12 +583,12 @@ def run_for_base_and_ref_values(
                         mtimes.append(os.stat(fn).st_mtime)
 
                     # Units are seconds
-                    changed_at = datetime.datetime.fromtimestamp(
+                    changed_at = time_utils.time_from_timestamp(
                         max(mtimes)
                     )
 
                     # Convert cache timestamp to seconds and compare
-                    cache_time = file_utils.time_from_timestamp(ts)
+                    cache_time = time_utils.time_from_timestring(ts)
 
                     # Use cache if it was produced *after* last change
                     if cache_time <= changed_at:
@@ -642,7 +641,7 @@ def run_for_base_and_ref_values(
                     # can't cache anything
                     try:
                         shelf[cache_key] = ref_result
-                        shelf[ts_key] = file_utils.timestamp()
+                        shelf[ts_key] = time_utils.timestring()
                     except Exception:
                         logging.log(
                             "Payload produced uncacheable reference"
